@@ -187,6 +187,7 @@ void tangle_actor_show(TangleActor* actor) {
 
 	if (TANGLE_ACTOR_IS_HIDING(actor) && !actor->priv->destroy) {
 		TANGLE_ACTOR_UNSET_FLAGS(actor, TANGLE_ACTOR_HIDING);
+		TANGLE_ACTOR_SET_FLAGS(actor, TANGLE_ACTOR_SHOWING);
 
 		clutter_animation_completed(actor->priv->hiding_animation);
 		g_object_unref(actor->priv->hiding_animation);
@@ -840,6 +841,7 @@ static void tangle_actor_allocate(ClutterActor* self, const ClutterActorBox* box
 	    old_allocation->x1 != new_allocation->x1 || old_allocation->x2 != new_allocation->x2 ||
 	    old_allocation->y1 != new_allocation->y1 || old_allocation->y2 != new_allocation->y2) {
 		if (!old_allocation) {
+			TANGLE_ACTOR_SET_FLAGS(actor, TANGLE_ACTOR_SHOWING);
 			actor->priv->transition_scale_children = TRUE;
 		}
 		animation = animate_transition(actor, old_allocation, new_allocation);
@@ -870,7 +872,11 @@ static void tangle_actor_paint(ClutterActor* clutter_actor) {
 }
 
 static void tangle_actor_pick(ClutterActor* clutter_actor, const ClutterColor* color) {
-	if (!TANGLE_ACTOR_IS_HIDING(TANGLE_ACTOR(clutter_actor))) {
+	TangleActor* actor;
+	
+	actor = TANGLE_ACTOR(clutter_actor);
+
+	if (!TANGLE_ACTOR_IS_HIDING(actor) && !TANGLE_ACTOR_IS_SHOWING(actor)) {
 		CLUTTER_ACTOR_CLASS(tangle_actor_parent_class)->pick(clutter_actor, color);
 	}
 }
@@ -1707,8 +1713,9 @@ static void on_transition_animation_completed(ClutterAnimation* animation, gpoin
 	vault = TANGLE_VAULT(user_data);
 	tangle_vault_get(vault, 3, TANGLE_TYPE_ACTOR, &actor, CLUTTER_TYPE_ACTOR_BOX, &from_allocation, CLUTTER_TYPE_ACTOR_BOX, &to_allocation);
 	g_signal_emit(actor, signals[TRANSITION_COMPLETED], 0, from_allocation, to_allocation);
-	if (!from_allocation) {
+	if (TANGLE_ACTOR_IS_SHOWING(actor)) {
 		g_signal_emit(actor, signals[SHOW_COMPLETED], 0, to_allocation);
+		TANGLE_ACTOR_UNSET_FLAGS(actor, TANGLE_ACTOR_SHOWING);
 	}
 	clutter_actor_box_free(from_allocation);
 	clutter_actor_box_free(to_allocation);
@@ -1724,8 +1731,9 @@ static ClutterAnimation* animate_transition(TangleActor* actor, ClutterActorBox*
 		tangle_signal_connect_vault(animation, "completed", G_CALLBACK(on_transition_animation_completed), vault);
 	} else {
 		g_signal_emit(actor, signals[TRANSITION_COMPLETED], 0, from_allocation, to_allocation);
-		if (!from_allocation) {
+		if (TANGLE_ACTOR_IS_SHOWING(actor)) {
 			g_signal_emit(actor, signals[SHOW_COMPLETED], 0, to_allocation);
+			TANGLE_ACTOR_UNSET_FLAGS(actor, TANGLE_ACTOR_SHOWING);
 		}
 	}
 
