@@ -28,7 +28,8 @@
 typedef enum {
 	TANGLE_ACTOR_ON_SCREEN = 1 << 0,
 	TANGLE_ACTOR_ALLOCATED = 1 << 1,
-	TANGLE_ACTOR_HIDING = 1 << 2
+	TANGLE_ACTOR_HIDING = 1 << 2,
+	TANGLE_ACTOR_SHOWING = 1 << 3
 } TangleActorFlags;
 
 typedef struct _TangleActor TangleActor;
@@ -70,6 +71,7 @@ GType tangle_actor_get_type (void) G_GNUC_CONST;
 #define TANGLE_ACTOR_IS_MAPPED_ON_SCREEN(a) (CLUTTER_ACTOR_IS_MAPPED(a) && ((((TangleActor*)(a))->flags & TANGLE_ACTOR_ON_SCREEN) != FALSE))
 #define TANGLE_ACTOR_IS_ALLOCATED(a) ((((TangleActor*)(a))->flags & TANGLE_ACTOR_ALLOCATED) != FALSE)
 #define TANGLE_ACTOR_IS_HIDING(a) ((((TangleActor*)(a))->flags & TANGLE_ACTOR_HIDING) != FALSE)
+#define TANGLE_ACTOR_IS_SHOWING(a) ((((TangleActor*)(a))->flags & TANGLE_ACTOR_SHOWING) != FALSE)
 
 ClutterAnimation* tangle_actor_animate(TangleActor* actor, gulong mode, guint duration, const gchar* first_property_name, ...);
 ClutterAnimation* tangle_actor_animate_with_timeline(TangleActor* actor, gulong mode, ClutterTimeline* timeline, const gchar* first_property_name, ...);
