@@ -34,8 +34,9 @@ struct _TangleAnyEvent {
 struct _TangleInteractionEvent {
 	TangleEventType type;
 	TangleActor* sender;
-	gboolean x_axis;
-	gboolean y_axis;
+	guint x_axis : 1;
+	guint y_axis : 1;
+	guint dragging : 1;
 };
 
 union _TangleEvent {
