@@ -331,10 +331,6 @@ static void tangle_floating_actor_get_property(GObject* object, guint prop_id, G
         }
 }
 
-static void tangle_floating_actor_finalize(GObject* object) {
-	G_OBJECT_CLASS(tangle_floating_actor_parent_class)->finalize(object);
-}
-
 static void tangle_floating_actor_dispose(GObject* object) {
 	TangleFloatingActor* floating_actor;
 	
@@ -351,7 +347,6 @@ static void tangle_floating_actor_class_init(TangleFloatingActorClass* floating_
 	TangleActorClass* actor_class = TANGLE_ACTOR_CLASS(floating_actor_class);
 	TangleWrapperActorClass* wrapper_actor_class = TANGLE_WRAPPER_ACTOR_CLASS(floating_actor_class);
 
-	gobject_class->finalize = tangle_floating_actor_finalize;
 	gobject_class->dispose = tangle_floating_actor_dispose;
 	gobject_class->set_property = tangle_floating_actor_set_property;
 	gobject_class->get_property = tangle_floating_actor_get_property;
