@@ -8,6 +8,7 @@
  */
 
 #include "tangle-scrollbar.h"
+#include "tangle-misc.h"
 
 /**
  * SECTION:tangle-scrollbar
@@ -166,11 +167,13 @@ static void tangle_scrollbar_get_property(GObject* object, guint prop_id, GValue
         }
 }
 
-static void tangle_scrollbar_finalize(GObject* object) {
-	G_OBJECT_CLASS(tangle_scrollbar_parent_class)->finalize(object);
-}
-
 static void tangle_scrollbar_dispose(GObject* object) {
+	TangleScrollbar* scrollbar;
+	
+	scrollbar = TANGLE_SCROLLBAR(object);
+	
+	TANGLE_UNREF_AND_NULLIFY_OBJECT_POINTER(scrollbar->priv->bar_actor);
+
 	G_OBJECT_CLASS(tangle_scrollbar_parent_class)->dispose(object);
 }
 
@@ -178,7 +181,6 @@ static void tangle_scrollbar_class_init(TangleScrollbarClass* scrollbar_class) {
 	GObjectClass* gobject_class = G_OBJECT_CLASS(scrollbar_class);
 	ClutterActorClass* clutter_actor_class = CLUTTER_ACTOR_CLASS(scrollbar_class);
 
-	gobject_class->finalize = tangle_scrollbar_finalize;
 	gobject_class->dispose = tangle_scrollbar_dispose;
 	gobject_class->set_property = tangle_scrollbar_set_property;
 	gobject_class->get_property = tangle_scrollbar_get_property;
