@@ -136,12 +136,14 @@ static gboolean tangle_scrolling_actor_button_press_event(ClutterActor* actor, C
 		
 	scrolling_actor = TANGLE_SCROLLING_ACTOR(actor);
 
-	scrolling_actor->priv->start_motion_x = event->x;
-	scrolling_actor->priv->start_motion_y = event->y;
-	scrolling_actor->priv->start_scrolling_offset_x = scrolling_actor->priv->scrolling_offset_x;
-	scrolling_actor->priv->start_scrolling_offset_y = scrolling_actor->priv->scrolling_offset_y;
-	scrolling_actor->priv->scrolling_effective = FALSE;
-	scrolling_actor->priv->captured_event_handler_id = g_signal_connect(clutter_actor_get_stage(actor), "captured-event", G_CALLBACK(on_captured_event), scrolling_actor);
+	if (!scrolling_actor->priv->captured_event_handler_id) {
+		scrolling_actor->priv->start_motion_x = event->x;
+		scrolling_actor->priv->start_motion_y = event->y;
+		scrolling_actor->priv->start_scrolling_offset_x = scrolling_actor->priv->scrolling_offset_x;
+		scrolling_actor->priv->start_scrolling_offset_y = scrolling_actor->priv->scrolling_offset_y;
+		scrolling_actor->priv->scrolling_effective = FALSE;
+		scrolling_actor->priv->captured_event_handler_id = g_signal_connect(clutter_actor_get_stage(actor), "captured-event", G_CALLBACK(on_captured_event), scrolling_actor);
+	}
 
 	return FALSE;
 }
@@ -254,11 +256,16 @@ static void tangle_scrolling_actor_get_property(GObject* object, guint prop_id,
         }
 }
 
-static void tangle_scrolling_actor_finalize(GObject* object) {
-	G_OBJECT_CLASS(tangle_scrolling_actor_parent_class)->finalize(object);
-}
-
 static void tangle_scrolling_actor_dispose(GObject* object) {
+	TangleScrollingActor* scrolling_actor;
+	
+	scrolling_actor = TANGLE_SCROLLING_ACTOR(object);
+	
+	if (scrolling_actor->priv->captured_event_handler_id) {
+		g_signal_handler_disconnect(scrolling_actor, scrolling_actor->priv->captured_event_handler_id);
+		scrolling_actor->priv->captured_event_handler_id = 0;
+	}
+
 	G_OBJECT_CLASS(tangle_scrolling_actor_parent_class)->dispose(object);
 }
 
@@ -268,7 +275,6 @@ static void tangle_scrolling_actor_class_init(TangleScrollingActorClass* scrolli
 	TangleActorClass* actor_class = TANGLE_ACTOR_CLASS(scrolling_actor_class);
 	TangleWrapperActorClass* wrapper_actor_class = TANGLE_WRAPPER_ACTOR_CLASS(scrolling_actor_class);
 
-	gobject_class->finalize = tangle_scrolling_actor_finalize;
 	gobject_class->dispose = tangle_scrolling_actor_dispose;
 	gobject_class->set_property = tangle_scrolling_actor_set_property;
 	gobject_class->get_property = tangle_scrolling_actor_get_property;
@@ -376,6 +382,7 @@ static gboolean on_captured_event(ClutterActor* actor, ClutterEvent* event, gpoi
 			tangle_scrolling_actor_set_scrolling_offset_y(scrolling_actor, scrolling_actor->priv->start_scrolling_offset_y - dy);
 			if (event->type == CLUTTER_BUTTON_RELEASE) {
 				g_signal_handler_disconnect(actor, scrolling_actor->priv->captured_event_handler_id);
+				scrolling_actor->priv->captured_event_handler_id = 0;
 				send_interaction_event(TANGLE_ACTOR(scrolling_actor), FALSE);
 			}
 		} else {
@@ -387,6 +394,7 @@ static gboolean on_captured_event(ClutterActor* actor, ClutterEvent* event, gpoi
 				send_interaction_event(TANGLE_ACTOR(scrolling_actor), TRUE);
 			} else if (event->type == CLUTTER_BUTTON_RELEASE) {
 				g_signal_handler_disconnect(actor, scrolling_actor->priv->captured_event_handler_id);
+				scrolling_actor->priv->captured_event_handler_id = 0;
 			}
 		}
 
