@@ -12,6 +12,7 @@
 #include "tangle-stylable.h"
 #include "tangle-template.h"
 #include "tangle-action.h"
+#include "tangle-misc.h"
 #include "marshalers.h"
 
 /**
@@ -228,10 +229,23 @@ static void tangle_style_get_property(GObject* object, guint prop_id, GValue* va
 }
 
 static void tangle_style_finalize(GObject* object) {
+	TangleStyle* style;
+	
+	style = TANGLE_STYLE(object);
+
+	g_free(style->priv->for_class);
+	g_free(style->priv->for_name);
+
 	G_OBJECT_CLASS(tangle_style_parent_class)->finalize(object);
 }
 
 static void tangle_style_dispose(GObject* object) {
+	TangleStyle* style;
+	
+	style = TANGLE_STYLE(object);
+	
+	TANGLE_UNREF_AND_NULLIFY_OBJECT_POINTER(style->priv->style_properties);
+	
 	G_OBJECT_CLASS(tangle_style_parent_class)->dispose(object);
 }
 
