@@ -354,9 +354,9 @@ static void tangle_widget_paint(ClutterActor* actor) {
 	}
 }
 
-static void paint_actor_if_mapped_and_not_hiding(ClutterActor* actor) {
+static void paint_actor_if_mapped_and_not_hiding_or_showing(ClutterActor* actor) {
 	if (CLUTTER_ACTOR_IS_MAPPED(actor) &&
-	    (!TANGLE_IS_ACTOR(actor) || !TANGLE_ACTOR_IS_HIDING(TANGLE_ACTOR(actor)))) {
+	    (!TANGLE_IS_ACTOR(actor) || (!TANGLE_ACTOR_IS_HIDING(TANGLE_ACTOR(actor)) && !TANGLE_ACTOR_IS_SHOWING(TANGLE_ACTOR(actor))))) {
 		clutter_actor_paint(actor);
 	}
 }
@@ -371,7 +371,7 @@ static void tangle_widget_pick(ClutterActor* actor, const ClutterColor *color) {
 		CLUTTER_ACTOR_CLASS(tangle_widget_parent_class)->pick(actor, color);
 	}
 
-	g_list_foreach(widget->priv->children,(GFunc)paint_actor_if_mapped_and_not_hiding, NULL);
+	g_list_foreach(widget->priv->children,(GFunc)paint_actor_if_mapped_and_not_hiding_or_showing, NULL);
 }
 
 static void tangle_widget_get_preferred_width(TangleActor* actor, gfloat for_height, gboolean interacting, gfloat* min_width_p, gfloat* natural_width_p, gfloat* max_width_p) {
